/******************************************************  Flash Header  *******************************************************

	Red Rapids
	797 North Grove Rd
	Suite 101
	Richardson, TX 75081
	www.redrapids.com | support@redrapids.com

	Copyright 2018, Red Rapids, Inc.

*******************************************************  Flash Header  ******************************************************/

#ifndef _FLASH_H_
#define _FLASH_H_

#if defined(__cplusplus)
	extern "C" {
#endif

// Define the expected number of Red Rapids devices.
#define NUM_DEVICES		1

////////////////////////////////////////////////////////  Error Codes  ////////////////////////////////////////////////////////

// Define error codes returned by API functions.
#define BAD_SETTING			-500
#define MODEL_NUMBER			BAD_SETTING - 1
#define DAC_INTERPOLATE			BAD_SETTING - 2
#define DAC_PLL					BAD_SETTING - 3
#define DMA_BUFFER				BAD_SETTING - 4
#define PHASE_BREAK				BAD_SETTING - 5
#define CONFIG_FAIL			-520
#define CLOCK_NOSOL				CONFIG_FAIL - 1
#define CLOCK_LOCK				CONFIG_FAIL - 2
#define SYNTH_LOCK				CONFIG_FAIL - 3
#define SERDES_NOSOL			CONFIG_FAIL - 4
#define DAC_PLL_LOCK			CONFIG_FAIL - 5
#define DAC_DLL_LOCK			CONFIG_FAIL - 6
#define DAC_FIFO_RST			CONFIG_FAIL - 7
#define RUN_FAIL			-530
#define TIME_OUT				RUN_FAIL - 1
#define FLASH_ERROR				RUN_FAIL - 2

//////////////////////////////////////////////////////  Flash Constants  //////////////////////////////////////////////////////

// BAR numbers:
#define BAR0 0
#define BAR2 2

// BAR0 register names:
#define SOFTWARE_RESET 0x0000
#define ERROR_STATUS 0x0010
#define BPI_IF_CTL 0x0040
#define BPI_BUS 0x0048
#define GLOBAL_INT_MASK 0x0108

// BAR2 register names:
#define IDENTIFICATION 0x0000

// Flash commands:
#define BLANK_CHECK 0xBC
#define BLOCK_ERASE 0x20
#define BUFFERED_PROGRAM 0xE9
#define CONFIRM_COMMAND 0xD0
#define UNLOCK_BLOCK 0x60
#define READ_ARRAY 0xFF
#define READ_STATUS_REGISTER 0x70
#define CLEAR_STATUS_REGISTER 0x50
#define PROG_READ_CONFIG_REG1 0x60
#define PROG_READ_CONFIG_REG2 0x03
#define READ_ID 0x90

// Programmer commands:
#define ENABLE_COMMAND 0x00000000
#define SEGMENT_COMMAND 0x10000000
#define ADDRESS_COMMAND 0x20000000
#define WRITE_COMMAND 0x30000000
#define READ_COMMAND 0x40000000

// Constants set by the hardware.
#define BLOCK_SIZE 0x20000
#define BLOCK_COUNT 0x100
#define BUFFER_SIZE 0x200
#define PARTITION_SIZE 0x400000
#define PARTITION_COUNT 0x8
#define SEGMENT_COUNT 0x4
#define CMD_FIFO_BURST 0x100
#define TYP_ERASE_TIME 900000 //useconds
#define TYP_BUFPROG_TIME 1000 //useconds
#define TYP_BLNKCHK_TIME 3200 //useconds

#ifdef __cplusplus
}
#endif

#endif
