/*****************************************************  Global Functions  *****************************************************

	Red Rapids
	797 North Grove Rd
	Suite 101
	Richardson, TX 75081
	www.redrapids.com | support@redrapids.com

	The following functions are common to several Red Rapids applications.

	Rev History:	11-28-2018:		Initial release.

	Copyright 2018, Red Rapids, Inc.

*****************************************************  Global Functions  *****************************************************/

#include "RRadapter.h"
#include "flash.h"
#include "global_functions.h"

// Report the firmware revision date (MMDDYYYY).
// Returns the firmware revision date in hex format, but it is not a hex value (e.g. 04/27/2012 returns 0x04272012).
unsigned FirmwareRevision(s_Handle *p_HW)
{
	unsigned long long value = 0;

	Read64(p_HW, BAR2, IDENTIFICATION, &value);

	return (unsigned long)(value & 0xFFFFFFFFull);
}

// Report the model number of the device.
// Returns the model number in hex format, but it is not a hex value (e.g. Model 266 returns 0x266).
unsigned ModelNumber(s_Handle *p_HW)
{
	unsigned long long value = 0;

	Read64(p_HW, BAR2, IDENTIFICATION, &value);

	return (unsigned long)((value >> 32) & 0x00000FFFull);
}

// Issue a software reset that is equivalent to a power-on reset.
void SoftwareReset(s_Handle *p_HW)
{
	Write64(p_HW, BAR0, SOFTWARE_RESET, 0x0ull);
}
